@@ -32,16 +32,16 @@
 ContinuousLBModel::ContinuousLBModel( MatrixReal const& m_Dataij, ModelParameters const& Mparam)
                                     : ICoClustModel(Mparam)
                                     , m_Dataij_(m_Dataij)
-                                    , m_ClusterDataij_(Mparam_.nbRow_, Mparam_.nbCol_)
+                                    , m_ClusterDataij_(m_Dataij)
                                     , m_Dataij2_(m_Dataij_.square())
-                                    , m_Mukl_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Sigma2kl_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Sigma2kltemp_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Muklold1_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Muklold2_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Mukltemp_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Vjk2_(Mparam_.nbCol_, Mparam_.nbrowclust_)
-                                    , m_Uil2_(Mparam_.nbRow_, Mparam_.nbcolclust_)
+                                    , m_Mukl_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 0.)
+                                    , m_Sigma2kl_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 1.)
+                                    , m_Sigma2kltemp_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 1.)
+                                    , m_Muklold1_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 0.)
+                                    , m_Muklold2_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 0.)
+                                    , m_Mukltemp_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 0.)
+                                    , m_Vjk2_(Mparam_.nbCol_, Mparam_.nbrowclust_, 0.)
+                                    , m_Uil2_(Mparam_.nbRow_, Mparam_.nbcolclust_, 0.)
 {}
 
 ContinuousLBModel::ContinuousLBModel( MatrixReal const& m_Dataij
@@ -50,15 +50,16 @@ ContinuousLBModel::ContinuousLBModel( MatrixReal const& m_Dataij
                                     , ModelParameters const& Mparam)
                                     : ICoClustModel(Mparam,rowlabels,collabels)
                                     , m_Dataij_(m_Dataij)
+                                    , m_ClusterDataij_(m_Dataij)
                                     , m_Dataij2_(m_Dataij_.square())
-                                    , m_Mukl_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Sigma2kl_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Sigma2kltemp_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Muklold1_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Muklold2_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Mukltemp_(Mparam_.nbrowclust_, Mparam_.nbcolclust_)
-                                    , m_Vjk2_(Mparam_.nbCol_, Mparam_.nbrowclust_)
-                                    , m_Uil2_(Mparam_.nbRow_, Mparam_.nbcolclust_)
+                                    , m_Mukl_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 0.)
+                                    , m_Sigma2kl_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 1.)
+                                    , m_Sigma2kltemp_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 1.)
+                                    , m_Muklold1_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 0.)
+                                    , m_Muklold2_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 0.)
+                                    , m_Mukltemp_(Mparam_.nbrowclust_, Mparam_.nbcolclust_, 0.)
+                                    , m_Vjk2_(Mparam_.nbCol_, Mparam_.nbrowclust_, 0.)
+                                    , m_Uil2_(Mparam_.nbRow_, Mparam_.nbcolclust_, 0.)
 {}
 
 void ContinuousLBModel::logSumRows(MatrixReal& m_sumik)
